==> biings-ds-1.10.3.tgz: package/docs/table.md <==
<h6 class="subtitle is-5 has-text-grey">Component</h6><h1 class="title is-1 has-text-weight-bold">Table</h1>
<p class="subtitle is-5">
    <span class="has-text-weight-semibold">Table</span> presents data sets in an easily scannable and comparable way.
</p>

<hr class="is-large is-visible">

<div class="box has-background-white is-relaxed is-marginless">
    <table class="table">
        <thead>
            <tr>
                <th>First column</th>
                <th>Second column</th>
                <th>Third column</th>
                <th>Fourth column</th>
            </tr>
        </thead>
        <tbody>
            <tr>
                <td>Line 1</td>
                <td>detailed</td>
                <td>data</td>
                <td>set</td>
            </tr>
            <tr>
                <td>Line 2</td>
                <td>detailed</td>
                <td>data</td>
                <td>set</td>
            </tr>
            <tr class="has-background-white-ter">
                <td>Line 3</td>
                <td>this</td>
                <td>is</td>
                <td>selected</td>
            </tr>
            <tr>
                <td>Line 4</td>
                <td>detailed</td>
                <td>data</td>
                <td>set</td>
            </tr>
        </tbody>
    </table>
</div>

    <table class="table">
        <thead>
            <tr>
                <th>First column</th>
                <th>Second column</th>
                <th>Third column</th>
                <th>Fourth column</th>
            </tr>
        </thead>
        <tbody>
            <tr>
                <td>Line 1</td>
                <td>detailed</td>
                <td>data</td>
                <td>set</td>
            </tr>
            <tr class="has-background-white-ter">
                <td>Line 3</td>
                <td>This</td>
                <td>is</td>
                <td>selected</td>
            </tr>
        </tbody>
    </table>

<br>

?> **Table** supports most text and color modifiers.

<hr>

<div class="box is-bordered">
    More variations on &nbsp;→&nbsp; <a href="http://bulma.io/documentation/elements/table/" target="blank">Bulma / <strong>Table</strong></a>
</div>

==> biings-ds-1.14.3.tgz: package/docs/table.md <==
<h6 class="subtitle is-5 has-text-grey">Component</h6><h1 class="title is-1 has-text-weight-bold">Table</h1>
<p class="subtitle is-5">
    <span class="has-text-weight-semibold">Table</span> presents data sets in an easily scannable and comparable way.
</p>

<hr class="is-large is-visible">

<div class="box is-well is-relaxed is-marginless">
    <table class="table">
        <thead>
            <tr>
                <th>First column</th>
                <th>Second column</th>
                <th>Third column</th>
                <th>Fourth column</th>
            </tr>
        </thead>
        <tbody>
            <tr>
                <td>Line 1</td>
                <td>detailed</td>
                <td>data</td>
                <td>set</td>
            </tr>
            <tr>
                <td>Line 2</td>
                <td>detailed</td>
                <td>data</td>
                <td>set</td>
            </tr>
            <tr class="has-background-grey-lighter">
                <td>Line 3</td>
                <td>this</td>
                <td>is</td>
                <td>selected</td>
            </tr>
            <tr>
                <td>Line 4</td>
                <td>detailed</td>
                <td>data</td>
                <td>set</td>
            </tr>
        </tbody>
    </table>
</div>

    <table class="table">
        <thead>
            <tr>
                <th>First column</th>
                <th>Second column</th>
                <th>Third column</th>
                <th>Fourth column</th>
            </tr>
        </thead>
        <tbody>
            <tr>
                <td>Line 1</td>
                <td>detailed</td>
                <td>data</td>
                <td>set</td>
            </tr>
            <tr class="has-background-white-ter">
                <td>Line 3</td>
                <td>This</td>
                <td>is</td>
                <td>selected</td>
            </tr>
        </tbody>
    </table>
<br>

?> **Table** supports most text and color modifiers.

<hr>

<div class="box is-bordered">
    More variations on &nbsp;→&nbsp; <a href="http://bulma.io/documentation/elements/table/" target="blank">Bulma / <strong>Table</strong></a>
</div>
